@@ -3,30 +3,31 @@ module Haskoin.Store
     , StoreConfig(..)
     , StoreEvent(..)
     , withStore
-
     , module Haskoin.Store.BlockStore
     , module Haskoin.Store.Web
     , module Haskoin.Store.Database.Reader
     , module Haskoin.Store.Data
-
       -- * Cache
-    , CacheConfig (..)
+    , CacheConfig(..)
     , CacheT
-    , CacheError (..)
+    , CacheError(..)
     , withCache
     , connectRedis
-
+    , isInCache
+    , evictFromCache
       -- * Store Reader
-    , StoreRead (..)
-    , Limit
-    , Offset
-
+    , StoreReadBase(..)
+    , StoreReadExtra(..)
+    , Limits(..)
+    , Start(..)
       -- * Useful Fuctions
     , getTransaction
+    , getDefaultBalance
+    , getSpenders
+    , getActiveTxData
     , blockAtOrBefore
-
       -- * Other Data
-    , PubExcept (..)
+    , PubExcept(..)
     ) where
 
 import           Haskoin.Store.BlockStore
